==> mingw-w64-i686-openshadinglanguage-1.11.10.0-2-any.pkg.tar.zst: mingw32/lib/cmake/OSL/OSLConfig.cmake <==
# Copyright Contributors to the Open Shading Language project.
# SPDX-License-Identifier: BSD-3-Clause
# https://github.com/imageworks/OpenShadingLanguage


####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was Config.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

include(CMakeFindDependencyMacro)

# add here all the find_dependency() whenever switching to config based dependencies
if (2.5.3 VERSION_GREATER_EQUAL 2.5)
    find_dependency(OpenEXR 2.5.3)
    # N.B. Only do this for OpenEXR >= 2.5, difficult to rely on their
    # exported configs before that.
endif ()

find_dependency(OpenImageIO 2.2.9.0 REQUIRED)

set_and_check (OSL_INCLUDE_DIR "${_IMPORT_PREFIX}/include")
set_and_check (OSL_INCLUDES    "${_IMPORT_PREFIX}/include")
set_and_check (OSL_LIB_DIR     "${_IMPORT_PREFIX}/lib")

#...logic to determine installedPrefix from the own location...
#set (OSL_CONFIG_DIR  "${installedPrefix}/")

include ("${CMAKE_CURRENT_LIST_DIR}/OSLTargets.cmake")

check_required_components ("OSL")

==> mingw-w64-i686-openshadinglanguage-1.11.17.0-4-any.pkg.tar.zst: mingw32/lib/cmake/OSL/OSLConfig.cmake <==
# Copyright Contributors to the Open Shading Language project.
# SPDX-License-Identifier: BSD-3-Clause
# https://github.com/AcademySoftwareFoundation/OpenShadingLanguage


####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was Config.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

include(CMakeFindDependencyMacro)

# add here all the find_dependency() whenever switching to config based dependencies
if (2.5.8 VERSION_GREATER_EQUAL 3.0)
    find_dependency(Imath 2.5.8)
elseif (2.5.8 VERSION_GREATER_EQUAL 2.4 AND 1)
    find_dependency(IlmBase 2.5.8)
    find_dependency(OpenEXR 2.5.8)
    find_dependency(ZLIB 1.2.12)  # Because OpenEXR doesn't do it
    find_dependency(Threads)  # Because OpenEXR doesn't do it
endif ()


find_dependency(OpenImageIO 2.3.18.0 REQUIRED)

set_and_check (OSL_INCLUDE_DIR "${PACKAGE_PREFIX_DIR}/include")
set_and_check (OSL_INCLUDES    "${PACKAGE_PREFIX_DIR}/include")
set_and_check (OSL_LIB_DIR     "${PACKAGE_PREFIX_DIR}/lib")

#...logic to determine installedPrefix from the own location...
#set (OSL_CONFIG_DIR  "${installedPrefix}/")

include ("${CMAKE_CURRENT_LIST_DIR}/OSLTargets.cmake")

check_required_components ("OSL")
